==> speech-analytic-testing_1.12.1_database.tar.gz: database/mssql/procedures/DeleteAuditorEvaluationPlanByInteraction.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- ESTA FUNCION TIENE POR FINALIDAD ELIMINAR OTRAS EVALUACIONES PENDIENTES DE UNA INTERACCION CORRESPONDIENTES AL MISMO 
--  PLAN DE EVALUACION
CREATE PROCEDURE [dbo].[DeleteAuditorEvaluationPlanByInteraction] (
	@VCC Varchar(50) = NULL,
	@IdEvaluationPlan Varchar(50) = NULL,
	@IdInteraction Varchar(250) = NULL,
	@InteractionType Varchar(50) = NULL,
	@IsDraft BIT = NULL
) AS
BEGIN
	SET NOCOUNT ON
	DECLARE @EvaluationPlanMode Varchar(50) = NULL

	-- DECLARAMOS UNA VARIABLE PARA VERIFICAR EL TIPO DEL PLAN
	DECLARE @IS_MIXED_EVALUATION_PLAN BIT = 0

	-- CONSULTAMOS LA MODALIDAD DEL PLAN DE EVALUACION
	SELECT @EvaluationPlanMode = EP.[Modality],
			@IS_MIXED_EVALUATION_PLAN = IIF (EP.[Evaluation_Mode] = 'X', 1, 0)
		FROM [dbo].[EvaluationPlan] EP (NOLOCK)
		WHERE EP.[Instance] = @VCC
			AND EP.[ID] = @IdEvaluationPlan

	-- SI ES UN PLAN DE MODALIDAD COMPARTIDA(FREE) ELIMINAMOS LAS DEMAS EVALUACIONES DE LA MISMA INTERACCION QUE EXISTEN 
	--  PARA LOS OTROS AUDITORES
	IF (@EvaluationPlanMode = 'FREE')
	BEGIN 
		-- 
		IF @IsDraft = 1
		BEGIN
		SELECT * FROM [dbo].[AuditorEvaluationPlan] (NOLOCK)
			-- SI SE GUARDA COMO BORRADOR, INHABILITAMOS LOS DEMAS REGISTROS PARA AUDITORES
			UPDATE [dbo].[AuditorEvaluationPlan]
				SET [Status] = 0
				WHERE [Instance] = @VCC
					AND [IdEvaluationPlan] = @IdEvaluationPlan
					AND [IdInteraction] = @IdInteraction
					AND [InteractionType] = @InteractionType
					AND ISNULL([Completed], 0) = 0
					AND [StatusDescription] <> 'DRAFT'
		END
		ELSE 
		BEGIN
		    -- SI NO SE GUARDA COMO BORRADOR, ELIMINAMOS LOS DEMAS REGISTROS PARA OTROS AUDITORES
			DELETE [dbo].[AuditorEvaluationPlan]
				WHERE [Instance] = @VCC
					AND [IdEvaluationPlan] = @IdEvaluationPlan
					AND [IdInteraction] = @IdInteraction
					AND [InteractionType] = @InteractionType
					AND ISNULL([Completed], 0) = 0

			-- ELIMINAMOS LOS REGISTROS BORRADOR QUE SE GENERAN PARA PLANES MIXTOS
			IF @IS_MIXED_EVALUATION_PLAN = 1
				DELETE FROM [dbo].[EvaluationResult]
					WHERE [Instance] = @VCC
						AND [IdEvaluationPlan] = @IdEvaluationPlan
						AND [IdInteraction] =  @IdInteraction
						AND [InteractionType] = @InteractionType
						AND [IdAuditor] LIKE '%-DRAFT'
		END
	END 

	SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/DeleteAuditorEvaluationPlanByInteraction.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- ESTA FUNCION TIENE POR FINALIDAD ELIMINAR OTRAS EVALUACIONES PENDIENTES DE UNA INTERACCION CORRESPONDIENTES AL MISMO 
--  PLAN DE EVALUACION
CREATE PROCEDURE [dbo].[DeleteAuditorEvaluationPlanByInteraction] (
	@VCC Varchar(50) = NULL,
	@IdEvaluationPlan Varchar(50) = NULL,
	@IdInteraction Varchar(250) = NULL,
	@InteractionType Varchar(50) = NULL,
	@IsDraft BIT = NULL
) AS
BEGIN
	SET NOCOUNT ON
	DECLARE @EvaluationPlanMode Varchar(50) = NULL

	-- DECLARAMOS UNA VARIABLE PARA VERIFICAR EL TIPO DEL PLAN
	DECLARE @IS_MIXED_EVALUATION_PLAN BIT = 0

	-- CONSULTAMOS LA MODALIDAD DEL PLAN DE EVALUACION
	SELECT @EvaluationPlanMode = EP.[Modality],
			@IS_MIXED_EVALUATION_PLAN = IIF (EP.[Evaluation_Mode] = 'X', 1, 0)
		FROM [dbo].[EvaluationPlan] EP (NOLOCK)
		WHERE EP.[Instance] = @VCC
			AND EP.[ID] = @IdEvaluationPlan

	-- SI ES UN PLAN DE MODALIDAD COMPARTIDA(FREE) ELIMINAMOS LAS DEMAS EVALUACIONES DE LA MISMA INTERACCION QUE EXISTEN 
	--  PARA LOS OTROS AUDITORES
	IF (@EvaluationPlanMode = 'FREE')
	BEGIN 
		-- 
		IF @IsDraft = 1
		BEGIN
			-- SELECT * FROM [dbo].[AuditorEvaluationPlan] (NOLOCK)
			-- SI SE GUARDA COMO BORRADOR, INHABILITAMOS LOS DEMAS REGISTROS PARA AUDITORES
			UPDATE [dbo].[AuditorEvaluationPlan]
				SET [Status] = 0
				WHERE [Instance] = @VCC
					AND [IdEvaluationPlan] = @IdEvaluationPlan
					AND [IdInteraction] = @IdInteraction
					AND [InteractionType] = @InteractionType
					AND ISNULL([Completed], 0) = 0
					AND [StatusDescription] <> 'DRAFT'
		END
		ELSE 
		BEGIN
		    -- SI NO SE GUARDA COMO BORRADOR, ELIMINAMOS LOS DEMAS REGISTROS PARA OTROS AUDITORES
			DELETE [dbo].[AuditorEvaluationPlan]
				WHERE [Instance] = @VCC
					AND [IdEvaluationPlan] = @IdEvaluationPlan
					AND [IdInteraction] = @IdInteraction
					AND [InteractionType] = @InteractionType
					AND ISNULL([Completed], 0) = 0

			-- ELIMINAMOS LOS REGISTROS BORRADOR QUE SE GENERAN PARA PLANES MIXTOS
			IF @IS_MIXED_EVALUATION_PLAN = 1
				DELETE FROM [dbo].[EvaluationResult]
					WHERE [Instance] = @VCC
						AND [IdEvaluationPlan] = @IdEvaluationPlan
						AND [IdInteraction] =  @IdInteraction
						AND [InteractionType] = @InteractionType
						AND [IdAuditor] LIKE '%-DRAFT'
		END
	END 

	SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
